# Chinu9653's package

This is a sample Python package created by Chinu9653.

## Features
- Feature 1
- Feature 2

## Installation
Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `chinus-uploads`.

```bash
pip install chinus-uploads